# psm

Pypi Source Manager: fast switch between different Pypi Source: pypi, double, aliyun


This package is inspired by [Pana/nrm](https://github.com/Pana/nrm).

## Installation

```
pip install psm
```


## Usage

### list all pypi source

```
psm ls
```

### change pypi source

```
psm use douban
```